pub struct Apply {
pub file: PathBuf,
pub context: Option<PathBuf>,
pub dry_run: Option<bool>,
pub profile: Option<String>,
pub region: Option<String>,
pub workgroup: Option<String>,
pub output_location: Option<String>,
pub no_pretty: Option<bool>,
}Fields
file: PathBufTarget path to render. If the target path is a directory, the root folder must contains the index.sql file
context: Option<PathBuf>Change the context current working dir
dry_run: Option<bool>Dry-run
profile: Option<String>AWS Profile Set this option via environment variable: export AWS_PROFILE=default
region: Option<String>AWS Region Set this option via environment variable: export AWS_DEFAULT_REGION=us-east-1
workgroup: Option<String>AWS Athena Workgroup Set this option via environment variable: export AWS_WORKGROUP=primary
output_location: Option<String>AWS Athena output location
The location in Amazon S3 where your query results are stored
such as s3://path/to/query/bucket/
Set this option via environment variable: export AWS_OUTPUT_LOCATION=s3://bucket/
no_pretty: Option<bool>No pretty print for SQL